"""配置管理模块."""

import os
from pathlib import Path
from typing import List, Optional

import yaml
from pydantic import BaseModel, Field
from pydantic_settings import BaseSettings


class ServerConfig(BaseModel):
    """服务器配置."""
    host: str = "0.0.0.0"
    port: int = 8000
    api_key: str = Field(..., description="API 密钥")


class LoggingConfig(BaseModel):
    """日志配置."""
    level: str = "INFO"
    file: Optional[str] = None


class NotificationService(BaseModel):
    """通知服务配置."""
    name: str
    url: str
    enabled: bool = True


class NotificationTemplate(BaseModel):
    """通知模板."""
    title: str
    body: str


class NotificationTemplates(BaseModel):
    """通知模板集合."""
    sms: NotificationTemplate
    system: NotificationTemplate


class NotificationConfig(BaseModel):
    """通知配置."""
    services: List[NotificationService]
    templates: NotificationTemplates


class SecurityConfig(BaseModel):
    """安全配置."""
    allowed_ips: List[str] = []
    rate_limit: int = 60


class Config(BaseSettings):
    """应用配置."""
    server: ServerConfig
    logging: LoggingConfig
    notifications: NotificationConfig
    security: SecurityConfig

    @classmethod
    def load_from_file(cls, config_path: str = "config.yaml") -> "Config":
        """从 YAML 文件加载配置."""
        config_file = Path(config_path)
        if not config_file.exists():
            raise FileNotFoundError(f"配置文件不存在: {config_path}")
        
        with open(config_file, "r", encoding="utf-8") as f:
            config_data = yaml.safe_load(f)
        
        return cls(**config_data)


# 全局配置实例
_config: Optional[Config] = None


def get_config() -> Config:
    """获取全局配置实例."""
    global _config
    if _config is None:
        config_path = os.getenv("CONFIG_PATH", "config.yaml")
        _config = Config.load_from_file(config_path)
    return _config


def reload_config(config_path: str = "config.yaml") -> Config:
    """重新加载配置."""
    global _config
    _config = Config.load_from_file(config_path)
    return _config
